@@ -8,12 +8,15 @@
 #![warn(clippy::pedantic)]
 #![allow(clippy::match_bool)]
 #![allow(clippy::if_not_else)]
-#![allow(clippy::stutter)]
+#![allow(clippy::module_name_repetitions)]
 #![allow(clippy::similar_names)]
 #![allow(clippy::use_self)]
 #![allow(clippy::single_match_else)]
 #![allow(clippy::inline_always)]
 #![allow(clippy::partialeq_ne_impl)]
+#![allow(clippy::missing_errors_doc)]
+#![allow(clippy::non_ascii_literal)]
+#![allow(clippy::enum_variant_names)]
 // Note: If you change this remember to update `README.md`.  To do so run `cargo run`.
 //! # Cargo rdme
 //!
@@ -47,6 +50,13 @@
 //! Whenever change your crate’s documentation you just need to run `cargo rdme` to update your
 //! README file.
 //!
+//!
+//! ### Automatic transformations
+//!
+//! Cargo rdme will apply some automatic transformations to your documentation when generating the README file:
+//!
+//! 1. Rust code blocks starting with `#` will be omitted, just like in `rustdoc`.
+//!
 //! ## Config file
 //!
 //! If the default behavior of `cargo rdme` is not appropriate for your project you can crate a
@@ -69,14 +79,18 @@
 //! These setting can be overridden with command line flags.  Run `cargo rdme --help` for more
 //! information.
 //!
-//! # Integration with CI
+//! ## Integration with CI
 //!
 //! To verify that your README is up to date with your crate’s documentation you can run
 //! `cargo rdme --check`.  The exit code will be `0` if the README is up to date, or `2` if it’s
 //! not.
 
 use crate::options::{EntrypointOpt, LineTerminatorOpt};
-use cargo_rdme::{infer_line_terminator, inject_doc, LineTerminator, Project};
+use cargo_rdme::transform::DocTransform;
+use cargo_rdme::{
+    extract_doc_from_source_file, infer_line_terminator, inject_doc_in_readme, LineTerminator,
+    Project,
+};
 use cargo_rdme::{Doc, ProjectError, Readme};
 use std::path::{Path, PathBuf};
 use thiserror::Error;
@@ -91,8 +105,8 @@ const EXIT_CODE_CHECK: i32 = 2;
 enum RunError {
     #[error("failed to get project info: {0}")]
     ProjectError(cargo_rdme::ProjectError),
-    #[error("failed to process rust doc: {0}")]
-    DocError(cargo_rdme::DocError),
+    #[error("failed to extract rust doc: {0}")]
+    ExtractDocError(cargo_rdme::ExtractDocError),
     #[error("failed to process README: {0}")]
     ReadmeError(cargo_rdme::ReadmeError),
     #[error("failed get crate's entry source file")]
@@ -113,9 +127,9 @@ impl From<cargo_rdme::ProjectError> for RunError {
     }
 }
 
-impl From<cargo_rdme::DocError> for RunError {
-    fn from(e: cargo_rdme::DocError) -> RunError {
-        RunError::DocError(e)
+impl From<cargo_rdme::ExtractDocError> for RunError {
+    fn from(e: cargo_rdme::ExtractDocError) -> RunError {
+        RunError::ExtractDocError(e)
     }
 }
 
@@ -170,13 +184,18 @@ fn run(current_dir_path: impl AsRef<Path>, options: options::Options) -> Result<
     let project: Project = Project::from_dir(current_dir_path)?;
     let entryfile: PathBuf =
         entrypoint(&project, options.entrypoint).ok_or(RunError::NoEntrySourceFile)?;
-    let doc: Doc = match Doc::from_source_file(entryfile)? {
+    let doc: Doc = match extract_doc_from_source_file(entryfile)? {
         None => return Err(RunError::NoRustdoc),
         Some(doc) => doc,
     };
+
+    let transform =
+        cargo_rdme::transform::rust_remove_comments::DocTransformRemoveRustComments::new();
+    let doc = transform.transform(&doc).unwrap();
+
     let readme_path: PathBuf = project.get_readme_path().ok_or(RunError::NoReadmeFile)?;
     let original_readme: Readme = Readme::from_file(&readme_path)?;
-    let new_readme: Readme = inject_doc(&original_readme, &doc)?;
+    let new_readme: Readme = inject_doc_in_readme(&original_readme, &doc)?;
 
     let line_terminator = match options.line_terminator {
         LineTerminatorOpt::Auto => infer_line_terminator(&readme_path)?,
